@@ -11,7 +11,7 @@ use warnings;
 use base qw( IO::Async::Notifier );
 IO::Async::Notifier->VERSION( '0.63' ); # adopt_future
 
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 $VERSION = eval $VERSION;
 
 use Carp;
@@ -174,6 +174,7 @@ sub _init
          fail_on_error => 1,
          max_connections_per_host => 3, # allow 2 longpolls + 1 actual command
          user_agent => __PACKAGE__,
+         pipeline => 0,
       );
       $self->add_child( $ua );
       $ua
@@ -405,6 +406,7 @@ sub login
 
    if( defined $params{user_id} and defined $params{access_token} ) {
       $self->{$_} = $params{$_} for qw( user_id access_token );
+      $self->configure( notifier_name => "uid=$params{user_id}" );
       $self->start;
       return Future->done( $self );
    }
@@ -589,6 +591,11 @@ sub start
                my $state = $_->{state};
 
                my $room = $self->_get_or_make_room( $room_id );
+
+               ## Placate odd synapse bug wherein some rooms appear twice in
+               ##   initialSync
+               next if $room->await_synced->is_ready;
+
                $room->_handle_event_initial( $_ ) for @$state;
 
                $room->await_synced->done;
