@@ -15,7 +15,7 @@ our @EXPORT = qw(
 );
 
 use HTTP::Response;
-use JSON qw( encode_json );
+use JSON::MaybeXS qw( encode_json );
 
 use constant EVENTS_PATH => "/_matrix/client/api/v1/events";
 
